==> hadoop-apache-3.2.0-18-sources.jar: io/trino/hadoop/$internal/org/apache/commons/io/serialization/WildcardClassNameMatcher.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package io.trino.hadoop.$internal.org.apache.commons.io.serialization;

import io.trino.hadoop.$internal.org.apache.commons.io.FilenameUtils;

/**
 * A {@link ClassNameMatcher} that uses simplified regular expressions
 *  provided by {@link io.trino.hadoop.$internal.org.apache.commons.io.FilenameUtils#wildcardMatch(String, String) FilenameUtils.wildcardMatch}
 * <p>
 * This object is immutable and thread-safe.
 * </p>
 */  
final class WildcardClassNameMatcher implements ClassNameMatcher {

    private final String pattern;

    /**
     * Constructs an object based on the specified simplified regular expression.
     * 
     * @param pattern a {@link FilenameUtils#wildcardMatch} pattern.
     */
    public WildcardClassNameMatcher(String pattern) {
        this.pattern = pattern;
    }
    
    @Override
    public boolean matches(String className) {
        return FilenameUtils.wildcardMatch(className, pattern);
    }
}

==> hadoop-apache-3.3.5-2-sources.jar: io/trino/hadoop/$internal/org/apache/commons/io/serialization/WildcardClassNameMatcher.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package io.trino.hadoop.$internal.org.apache.commons.io.serialization;

import io.trino.hadoop.$internal.org.apache.commons.io.FilenameUtils;

/**
 * A {@link ClassNameMatcher} that uses simplified regular expressions
 *  provided by {@link io.trino.hadoop.$internal.org.apache.commons.io.FilenameUtils#wildcardMatch(String, String) FilenameUtils.wildcardMatch}
 * <p>
 * This object is immutable and thread-safe.
 * </p>
 */
final class WildcardClassNameMatcher implements ClassNameMatcher {

    private final String pattern;

    /**
     * Constructs an object based on the specified simplified regular expression.
     *
     * @param pattern a {@link FilenameUtils#wildcardMatch} pattern.
     */
    public WildcardClassNameMatcher(final String pattern) {
        this.pattern = pattern;
    }

    @Override
    public boolean matches(final String className) {
        return FilenameUtils.wildcardMatch(className, pattern);
    }
}
